@@ -6,7 +6,7 @@
 #' @param spdata data.frame containing the spectral data with the columns
 #'   'scope', 'dark', and 'white'
 #'
-compute_processed <- function(spdata) {
+lr_compute_processed <- function(spdata) {
 
   with(spdata, (scope - dark) / (white - dark) * 100)
 
