@@ -82,7 +82,8 @@ lr_parse_procspec <- function(filename) {
 
   author <- xml_text(xml_find_first(xml_source, ".//userName"))
   savetime <- xml_double(xml_find_first(xml_source, "//milliTime"))
-  savetime <- as.character(as.Date(savetime/(1000*60*60*24), origin = "1970-01-01"))
+  savetime <- as.POSIXct(savetime/1000, origin = "1970-01-01", tz = "UTC")
+  savetime <- format(savetime, tz = "UTC")
   specclass <- xml_text(xml_find_first(xml_source, ".//spectrometerClass"))
   specmodel <- gsub(".+\\.([[:alnum:]]+)$", "\\1", specclass)
   specID <- xml_text(xml_find_first(xml_source, ".//spectrometerSerialNumber"))
